@@ -4,5 +4,6 @@ var group__pw__conf =
     [ "pw_conf_load_conf_for_context", "group__pw__conf.html#gaa52671fea4670565deb7507ab2d059d1", null ],
     [ "pw_conf_load_conf", "group__pw__conf.html#ga75b61160deaaa5b8f55ec5ee8d4e9b2b", null ],
     [ "pw_conf_load_state", "group__pw__conf.html#ga4aec15c4b086542d8e8bde2127fbce2f", null ],
-    [ "pw_conf_save_state", "group__pw__conf.html#ga55397ea3e06d6d0ec92337ef705c34f2", null ]
+    [ "pw_conf_save_state", "group__pw__conf.html#ga55397ea3e06d6d0ec92337ef705c34f2", null ],
+    [ "pw_conf_match_rules", "group__pw__conf.html#gaf7600a908360fa6145956412f089c184", null ]
 ];
\ No newline at end of file
