@@ -62,28 +62,28 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "alloc_8h.html",
-"group__pw__client.html#gaffa5b807a9674495aa5c14a68d5fd88c",
-"group__pw__global.html#gae35b9eb5ebbdead2e5a79845d5fa2031",
-"group__pw__keys.html#gaa2b0c7062965986d9d8dbadf553eb6ba",
-"group__pw__node.html#ga5437fe007ac346f48f0f63fec8ca8b40",
-"group__pw__session__manager.html#ga2e7a34daf8b8253ed9bffd78cdca8e7f",
-"group__pwtest.html#ga2c915fce91d56c38b5f5a3c4e58c43b2",
-"group__spa__cpu.html#gaeaa02c7399c9c2e26501e6e220dd9910",
-"group__spa__json.html#ga9e5319ac5846fb6219a973e0cfa46786",
-"group__spa__names.html#gaf8c5034276b9d90ecb0c2581de0ada62",
-"group__spa__param.html#ga4c6b9dbf27cb5f8e564c2de697bfc175",
-"group__spa__param.html#gga339d759aafadca6ef623f32ce7e65be0a9c4a4f508012ae916946d2bc8f62c736",
-"group__spa__param.html#ggaaa66f9e8b1228f1ef1f2630d8d9c5ab5a12a939e254137ec3137f3600f7f8e5ee",
-"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43eaec4287ed05c95eba5c69a1c515e76f80",
-"group__spa__pod.html#gabdf6e06a4b3861a11841166dff9d04c3",
-"group__spa__utils__defs.html#ga48e64fde9ece326caf683b04597614a5",
-"page_objects_design.html#autotoc_md75",
-"structpw__client__node__events.html",
-"structpw__impl__module__events.html#a75c9588d21472e8d610b813bdd9a419e",
-"structpw__session__info.html#a00aaf0720fd58ae285a1fe122ab0fb93",
-"structspa__dict.html#a3b3b78bfe5fffe13a10720bb7099c399",
-"structspa__meta__header.html#aae54e5badad1945c2a49d64842df5b1f",
-"structspa__thread.html"
+"group__pw__client.html#gaf334e712707cd3d4fb97100f3baedeb0",
+"group__pw__global.html#gab6796dae933803798be1658f4020315c",
+"group__pw__keys.html#gaa039c0a911742213e239311ec73b623b",
+"group__pw__node.html#ga3c668f349296e6fcbf3b294b92274f1f",
+"group__pw__session__manager.html#ga1df3e3242c1438fe35c454dd3ed41219",
+"group__pwtest.html#ga135297caa69f5e14b2b20148850d080b",
+"group__spa__cpu.html#gad4c6b81675ec1a16c23239041970f099",
+"group__spa__json.html#ga6d871debd28993273c3cbb1b0f7fce64",
+"group__spa__names.html#gadc887e81536271d1538500da0fb6be1f",
+"group__spa__param.html#ga49c3cb2109aab971f92dfe13bde3759b",
+"group__spa__param.html#gga3338e5f0867a0e073d8dcfd309fe8850a682778cce4e3c92fa38ba77e8f838246",
+"group__spa__param.html#gga9c37ad62772233835d6bf5083a9e4613a3c01bfb4218e827d2d2f21385d71798e",
+"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43eaa9b46794cf9585c21b7880d238ce2355",
+"group__spa__pod.html#gab23072b3f0f817478e011658b3504161",
+"group__spa__utils__defs.html#ga01ba22304e834c86556e645614f65d84",
+"page_module_roc_sink.html",
+"structpw__client__events.html#a58af5a46ef2875bf85f2683ed522d254",
+"structpw__impl__link__events.html",
+"structpw__registry__events.html#a04c4f7cbbf5dcc0c54887862887dbc97",
+"structspa__device__events.html#a5b83e45fd5922657978cc36df24cc1c7",
+"structspa__loop__utils__methods.html#adc8b3b97121c94a824307117dad02989",
+"structspa__strbuf.html#ad1ee23ef60728cefba6d11341da61ef1"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
