@@ -1,5 +1,23 @@
 var NAVTREEINDEX15 =
 {
+"group__spa__utils__defs.html#ga01ba22304e834c86556e645614f65d84":[10,8,8,1,56],
+"group__spa__utils__defs.html#ga06647c110a0382a09bea681a14634f64":[10,8,8,1,20],
+"group__spa__utils__defs.html#ga0fb5b0492ff8bb640cbad9b2711c77d0":[10,8,8,1,64],
+"group__spa__utils__defs.html#ga1179685eef5a041a5c8e60a9a6483048":[10,8,8,1,25],
+"group__spa__utils__defs.html#ga1b605788d4782d77eb54b75f258413b9":[10,8,8,1,36],
+"group__spa__utils__defs.html#ga1f57dfee056b657ddcd2bc69a7f45bce":[10,8,8,1,55],
+"group__spa__utils__defs.html#ga2157cfb3de1793302e5d08958bdc8ab2":[10,8,8,1,71],
+"group__spa__utils__defs.html#ga26f69327ba25a67c5120805511190740":[10,8,8,1,65],
+"group__spa__utils__defs.html#ga2c939bee0863eddd75b264b2aaf316e0":[10,8,8,1,60],
+"group__spa__utils__defs.html#ga33e30c1bdbba747c8c00077913d48411":[10,8,8,1,22],
+"group__spa__utils__defs.html#ga3404aa33acd9e8316fb33ebd146446f0":[10,8,8,1,63],
+"group__spa__utils__defs.html#ga34890f84380ed041625fc0a252186bf2":[10,8,8,1,23],
+"group__spa__utils__defs.html#ga3625c72ccb164919faaf2a3c5a37e9c2":[10,8,8,1,79],
+"group__spa__utils__defs.html#ga3bca1a11d1c7e8404f9456580acf0676":[10,8,8,1,10],
+"group__spa__utils__defs.html#ga3d65c899d0f8937244ed2893d1841f6f":[10,8,8,1,46],
+"group__spa__utils__defs.html#ga3fecbba7e4f85f539f62c8db39f12b0a":[10,8,8,1,58],
+"group__spa__utils__defs.html#ga48e64fde9ece326caf683b04597614a5":[10,8,8,1,74],
+"group__spa__utils__defs.html#ga4a50fbd4b694e2826233b6d54ef3b5a8":[10,8,8,1,67],
 "group__spa__utils__defs.html#ga4a52677c41f0a787a3c6624f18647cb6":[10,8,8,1,43],
 "group__spa__utils__defs.html#ga57aec3d89182594c8fef7be284f41fff":[10,8,8,1,11],
 "group__spa__utils__defs.html#ga58dddf4d57e29beade3b44e156dea532":[10,8,8,1,15],
@@ -62,8 +80,8 @@ var NAVTREEINDEX15 =
 "group__spa__utils__defs.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1a48000c4ffb67d7fcba31225d2ca9600d":[10,8,8,1,83,0],
 "group__spa__utils__defs.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1ad27b9a94c88677dfa8681ec43abac456":[10,8,8,1,83,1],
 "h264_8h.html":[10,8,7,28],
-"hook_8h.html":[10,8,8,5,0],
 "hook_8h.html":[10,8,8,4,0],
+"hook_8h.html":[10,8,8,5,0],
 "iec958_8h.html":[10,8,7,2],
 "impl-client_8h.html":[10,5,0,0],
 "impl-core_8h.html":[10,5,1,0],
@@ -231,23 +249,5 @@ var NAVTREEINDEX15 =
 "page_module_protocol_simple.html":[6,19],
 "page_module_pulse_tunnel.html":[6,20],
 "page_module_raop_discover.html":[6,22],
-"page_module_raop_sink.html":[6,21],
-"page_module_roc_sink.html":[6,23],
-"page_module_roc_source.html":[6,24],
-"page_module_rt.html":[6,27],
-"page_module_rtp_sink.html":[6,25],
-"page_module_rtp_source.html":[6,26],
-"page_module_session_manager.html":[6,28],
-"page_module_x11_bell.html":[6,29],
-"page_module_zeroconf_discover.html":[6,30],
-"page_objects_design.html":[5,8],
-"page_objects_design.html#autotoc_md68":[5,8,0],
-"page_objects_design.html#autotoc_md69":[5,8,0,0],
-"page_objects_design.html#autotoc_md70":[5,8,0,1],
-"page_objects_design.html#autotoc_md71":[5,8,0,2],
-"page_objects_design.html#autotoc_md72":[5,8,1],
-"page_objects_design.html#autotoc_md73":[5,8,1,0],
-"page_objects_design.html#autotoc_md74":[5,8,1,0,0],
-"page_objects_design.html#autotoc_md75":[5,8,1,1],
-"page_objects_design.html#autotoc_md76":[5,8,1,2]
+"page_module_raop_sink.html":[6,21]
 };
