@@ -1,5 +1,26 @@
 var NAVTREEINDEX18 =
 {
+"structpw__impl__link__events.html":[10,5,4,1],
+"structpw__impl__link__events.html#a05b20c99f1014e62e0d032b92382f584":[10,5,4,1,5],
+"structpw__impl__link__events.html#a05c9fec1c6580f673d09e33005bca5ee":[10,5,4,1,0],
+"structpw__impl__link__events.html#a36d3179004ca94bfe99cfc7c7608321a":[10,5,4,1,4],
+"structpw__impl__link__events.html#a7cf5965ff2f975aba7ac061938e1fa9c":[10,5,4,1,2],
+"structpw__impl__link__events.html#a8e6dceaefdbbe793d1eba749370a3f25":[10,5,4,1,1],
+"structpw__impl__link__events.html#ad161d67256c9fd29f54cc53dbacb10d5":[10,5,4,1,6],
+"structpw__impl__link__events.html#ae136867ff703e789d52dbb2ef427726d":[10,5,4,1,3],
+"structpw__impl__metadata.html":[10,5,5,2],
+"structpw__impl__metadata__events.html":[10,5,5,1],
+"structpw__impl__metadata__events.html#a1f7feaad034d62902dccdef0a2b2f85a":[10,5,5,1,1],
+"structpw__impl__metadata__events.html#a2a0419974291d4e9360544e5618ffb0f":[10,5,5,1,3],
+"structpw__impl__metadata__events.html#a75ce933b493a16ecad3e8f9834cc74e6":[10,5,5,1,2],
+"structpw__impl__metadata__events.html#ac11ef017d8f59e0a28d1d882ac508b22":[10,5,5,1,0],
+"structpw__impl__module.html":[10,5,6,2],
+"structpw__impl__module__events.html":[10,5,6,1],
+"structpw__impl__module__events.html#a1f0de76c49fdf742fe40c6fc0799d08c":[10,5,6,1,3],
+"structpw__impl__module__events.html#a2cb2abff60d0fa2370afcb8b5c2ae830":[10,5,6,1,2],
+"structpw__impl__module__events.html#a4cfcceec669bbbdf6697e36cd5dbae1d":[10,5,6,1,1],
+"structpw__impl__module__events.html#a75c9588d21472e8d610b813bdd9a419e":[10,5,6,1,4],
+"structpw__impl__module__events.html#aea5e86ba050b1b9e92bb3c7ba3425f71":[10,5,6,1,0],
 "structpw__impl__node.html":[10,5,7,2],
 "structpw__impl__node__events.html":[10,5,7,1],
 "structpw__impl__node__events.html#a0c45913c502536b96684e02449475a18":[10,5,7,1,16],
@@ -19,9 +40,9 @@ var NAVTREEINDEX18 =
 "structpw__impl__node__events.html#abae73b060850e69368efdace5e1ddd68":[10,5,7,1,3],
 "structpw__impl__node__events.html#ac82d3cde1bc6a6b7a617f80b74c8dc9e":[10,5,7,1,14],
 "structpw__impl__node__events.html#adbaa329398d27871d25ddacad8a33c12":[10,5,7,1,11],
-"structpw__impl__port.html":[10,5,4,3],
-"structpw__impl__port.html":[10,5,7,3],
 "structpw__impl__port.html":[10,5,8,2],
+"structpw__impl__port.html":[10,5,7,3],
+"structpw__impl__port.html":[10,5,4,3],
 "structpw__impl__port__events.html":[10,5,8,1],
 "structpw__impl__port__events.html#a3e2788e02240c77076c32642e1d57c82":[10,5,8,1,8],
 "structpw__impl__port__events.html#a5595c734ed5c3fc9ab27c2f5244fa325":[10,5,8,1,1],
@@ -221,33 +242,12 @@ var NAVTREEINDEX18 =
 "structpw__proxy.html":[10,4,13,2],
 "structpw__proxy__events.html":[10,4,13,1],
 "structpw__proxy__events.html#a1d91d77027018205abcdfe5f25b0feb1":[10,4,13,1,4],
+"structpw__proxy__events.html#a220d199c1f0a241f1e623686863e8158":[10,4,13,1,6],
 "structpw__proxy__events.html#a25e8553fd0ed2f729ffe61994f6973a2":[10,4,13,1,0],
 "structpw__proxy__events.html#a8072b9d1ea7e1c91cce89de75d1c7e61":[10,4,13,1,3],
 "structpw__proxy__events.html#a8916a9be2fa3763221fdf64f79468d14":[10,4,13,1,2],
 "structpw__proxy__events.html#aaa8802aa5a62fdc422f8db0d606adac3":[10,4,13,1,1],
 "structpw__proxy__events.html#af8e0510a58d92ddd0831293e1c42b867":[10,4,13,1,5],
 "structpw__registry.html":[10,4,4,5],
-"structpw__registry__events.html":[10,4,14,1],
-"structpw__registry__events.html#a04c4f7cbbf5dcc0c54887862887dbc97":[10,4,14,1,2],
-"structpw__registry__events.html#a37bd7089a7a07d7154e111e67b25f96c":[10,4,14,1,1],
-"structpw__registry__events.html#a94464d7de86207e80a3dff93974b1a01":[10,4,14,1,0],
-"structpw__registry__methods.html":[10,4,14,2],
-"structpw__registry__methods.html#a743174c4df93282f1361f137383cb41a":[10,4,14,2,2],
-"structpw__registry__methods.html#a82488a74c02c5b764b0764b0d3e42fac":[10,4,14,2,0],
-"structpw__registry__methods.html#a91a13e6dbf685af929ced294d5816089":[10,4,14,2,1],
-"structpw__registry__methods.html#afe6865901f9bc87f009674959d12e60c":[10,4,14,2,3],
-"structpw__resource.html":[10,5,14,2],
-"structpw__resource__events.html":[10,5,14,1],
-"structpw__resource__events.html#a0472df3f84251f7c7f5a36692bd0ac6e":[10,5,14,1,1],
-"structpw__resource__events.html#a0a276ed65fe8f88887e9fbd0d08df018":[10,5,14,1,2],
-"structpw__resource__events.html#a41e29d4a60ff80ff183c2cb56060f7e9":[10,5,14,1,0],
-"structpw__resource__events.html#af8ab8db63d0b4e3a332ff552e416e5a2":[10,5,14,1,3],
-"structpw__session.html":[10,7,4,24],
-"structpw__session__events.html":[10,7,4,10],
-"structpw__session__events.html#a36371c5decff93c9c0c0688c19b2780c":[10,7,4,10,1],
-"structpw__session__events.html#a6d9e402e306432f33e6fe085599416d7":[10,7,4,10,2],
-"structpw__session__events.html#a9156a82a54dba4f5e6f7b045a31b5ac7":[10,7,4,10,0],
-"structpw__session__info.html":[10,7,4,18],
-"structpw__session__info.html#a00aaf0720fd58ae285a1fe122ab0fb93":[10,7,4,18,3],
-"structpw__session__info.html#a1289ec21ec9441f29314a561b341cf13":[10,7,4,18,2]
+"structpw__registry__events.html":[10,4,14,1]
 };
