@@ -1,5 +1,27 @@
 var NAVTREEINDEX19 =
 {
+"structpw__registry__events.html#a04c4f7cbbf5dcc0c54887862887dbc97":[10,4,14,1,2],
+"structpw__registry__events.html#a37bd7089a7a07d7154e111e67b25f96c":[10,4,14,1,1],
+"structpw__registry__events.html#a94464d7de86207e80a3dff93974b1a01":[10,4,14,1,0],
+"structpw__registry__methods.html":[10,4,14,2],
+"structpw__registry__methods.html#a743174c4df93282f1361f137383cb41a":[10,4,14,2,2],
+"structpw__registry__methods.html#a82488a74c02c5b764b0764b0d3e42fac":[10,4,14,2,0],
+"structpw__registry__methods.html#a91a13e6dbf685af929ced294d5816089":[10,4,14,2,1],
+"structpw__registry__methods.html#afe6865901f9bc87f009674959d12e60c":[10,4,14,2,3],
+"structpw__resource.html":[10,5,14,2],
+"structpw__resource__events.html":[10,5,14,1],
+"structpw__resource__events.html#a0472df3f84251f7c7f5a36692bd0ac6e":[10,5,14,1,1],
+"structpw__resource__events.html#a0a276ed65fe8f88887e9fbd0d08df018":[10,5,14,1,2],
+"structpw__resource__events.html#a41e29d4a60ff80ff183c2cb56060f7e9":[10,5,14,1,0],
+"structpw__resource__events.html#af8ab8db63d0b4e3a332ff552e416e5a2":[10,5,14,1,3],
+"structpw__session.html":[10,7,4,24],
+"structpw__session__events.html":[10,7,4,10],
+"structpw__session__events.html#a36371c5decff93c9c0c0688c19b2780c":[10,7,4,10,1],
+"structpw__session__events.html#a6d9e402e306432f33e6fe085599416d7":[10,7,4,10,2],
+"structpw__session__events.html#a9156a82a54dba4f5e6f7b045a31b5ac7":[10,7,4,10,0],
+"structpw__session__info.html":[10,7,4,18],
+"structpw__session__info.html#a00aaf0720fd58ae285a1fe122ab0fb93":[10,7,4,18,3],
+"structpw__session__info.html#a1289ec21ec9441f29314a561b341cf13":[10,7,4,18,2],
 "structpw__session__info.html#aa2d06aa8a36c3da1890e37f02e4702a6":[10,7,4,18,1],
 "structpw__session__info.html#aa58e4f042f5cf3226d0765654439a9a3":[10,7,4,18,0],
 "structpw__session__info.html#abfebf0a6ad9331c4690ffad37894d660":[10,7,4,18,4],
@@ -77,14 +99,15 @@ var NAVTREEINDEX19 =
 "structspa__audio__aec__methods.html#af7b0dbc68aecaab0c278bc95a9d37503":[11,0,140,2],
 "structspa__audio__info.html":[10,8,7,34],
 "structspa__audio__info.html#a07b9f000b469ff8389b93290a5a06b2b":[10,8,7,34,5],
+"structspa__audio__info.html#a0c0ba9b2cb3625fdbfa3a5f1a00639d3":[10,8,7,34,16],
 "structspa__audio__info.html#a1042e506082d62d0c5371c3d9d349a9a":[10,8,7,34,8],
 "structspa__audio__info.html#a1831d447b0446ff947e879f2de34d410":[10,8,7,34,3],
-"structspa__audio__info.html#a1c0fd971fb059d844722a21feeb3de59":[10,8,7,34,15],
 "structspa__audio__info.html#a41f273519b13112d24c1a7066755e3d8":[10,8,7,34,11],
 "structspa__audio__info.html#a5470ad19233fb9e3136d500296a74d75":[10,8,7,34,1],
 "structspa__audio__info.html#a5d87c4474c9eb1a61153dd460599591b":[10,8,7,34,6],
 "structspa__audio__info.html#a635122b47bf1de20dd009ecca6cdb7d3":[10,8,7,34,10],
 "structspa__audio__info.html#a755a925f66d28b0e9912482e97375b7a":[10,8,7,34,2],
+"structspa__audio__info.html#a880d36c25907b88e7ca3dc34d200c343":[10,8,7,34,15],
 "structspa__audio__info.html#a9128e8bd148abec71d6261dc5af9a7d9":[10,8,7,34,14],
 "structspa__audio__info.html#a9782c7a01047c3a1058fd8dd40c5f52b":[10,8,7,34,7],
 "structspa__audio__info.html#a99282e01caf417fe4ee63458ccdb6b30":[10,8,7,34,0],
@@ -126,24 +149,27 @@ var NAVTREEINDEX19 =
 "structspa__audio__info__mp3.html":[11,0,150],
 "structspa__audio__info__mp3.html#a2066d86c3d391a097c57441f8c391234":[11,0,150,0],
 "structspa__audio__info__mp3.html#a9eab81f1ef553124803e7563d7ffce93":[11,0,150,1],
-"structspa__audio__info__ra.html":[11,0,151],
-"structspa__audio__info__ra.html#a281cd0f54656e1ccfda03854e5d36ce2":[11,0,151,1],
-"structspa__audio__info__ra.html#aa5374f33cf4a773ca3bb779d3e199fc9":[11,0,151,0],
+"structspa__audio__info__opus.html":[11,0,151],
+"structspa__audio__info__opus.html#ab354cfeab8ed9e4561332f86f77f5397":[11,0,151,1],
+"structspa__audio__info__opus.html#abf65d8f7d0877d50068bb68cff1f3e44":[11,0,151,0],
+"structspa__audio__info__ra.html":[11,0,152],
+"structspa__audio__info__ra.html#a281cd0f54656e1ccfda03854e5d36ce2":[11,0,152,1],
+"structspa__audio__info__ra.html#aa5374f33cf4a773ca3bb779d3e199fc9":[11,0,152,0],
 "structspa__audio__info__raw.html":[10,8,7,37],
 "structspa__audio__info__raw.html#a542692f9d3518632e37ea575d13ca149":[10,8,7,37,0],
 "structspa__audio__info__raw.html#a5a7e0c093143ba0820e936ece11f0952":[10,8,7,37,3],
 "structspa__audio__info__raw.html#a696f18b889bb8a5496e16dd48f7d8e01":[10,8,7,37,1],
 "structspa__audio__info__raw.html#ac21ae45356ef4e1dbfde141937fde9c5":[10,8,7,37,4],
 "structspa__audio__info__raw.html#ae7e501bbfbef2cd75f3ae0f13719652c":[10,8,7,37,2],
-"structspa__audio__info__vorbis.html":[11,0,153],
-"structspa__audio__info__vorbis.html#a7614ad24e4491223d0d44c1931c3089b":[11,0,153,0],
-"structspa__audio__info__vorbis.html#afec5882d3af8e9d177b4b0771c176046":[11,0,153,1],
-"structspa__audio__info__wma.html":[11,0,154],
-"structspa__audio__info__wma.html#a08102a7049195a3a9f5b734a6b8f7be5":[11,0,154,1],
-"structspa__audio__info__wma.html#a0bf6e6bad02abf194f2d65b5b458e7ba":[11,0,154,4],
-"structspa__audio__info__wma.html#a328501d7905f732937932d3731916a55":[11,0,154,3],
-"structspa__audio__info__wma.html#a46f090f295f02f54aaa427abb93d44e2":[11,0,154,2],
-"structspa__audio__info__wma.html#ad572e9079c943a87b18d96060ced5af4":[11,0,154,0],
+"structspa__audio__info__vorbis.html":[11,0,154],
+"structspa__audio__info__vorbis.html#a7614ad24e4491223d0d44c1931c3089b":[11,0,154,0],
+"structspa__audio__info__vorbis.html#afec5882d3af8e9d177b4b0771c176046":[11,0,154,1],
+"structspa__audio__info__wma.html":[11,0,155],
+"structspa__audio__info__wma.html#a08102a7049195a3a9f5b734a6b8f7be5":[11,0,155,1],
+"structspa__audio__info__wma.html#a0bf6e6bad02abf194f2d65b5b458e7ba":[11,0,155,4],
+"structspa__audio__info__wma.html#a328501d7905f732937932d3731916a55":[11,0,155,3],
+"structspa__audio__info__wma.html#a46f090f295f02f54aaa427abb93d44e2":[11,0,155,2],
+"structspa__audio__info__wma.html#ad572e9079c943a87b18d96060ced5af4":[11,0,155,0],
 "structspa__audio__layout__info.html":[10,8,7,36],
 "structspa__audio__layout__info.html#a939d325d78f6c2cb4492fda99fe3efd0":[10,8,7,36,1],
 "structspa__audio__layout__info.html#abd815a9154f329d6a02f84f222bca93a":[10,8,7,36,0],
@@ -223,31 +249,5 @@ var NAVTREEINDEX19 =
 "structspa__device.html":[10,8,4,3],
 "structspa__device.html#a00d8f19734c35525e99ecaab33113d3f":[10,8,4,3,0],
 "structspa__device__events.html":[10,8,4,7],
-"structspa__device__events.html#a0b9ba211d7f484c7df9ac269d5b49af3":[10,8,4,7,2],
-"structspa__device__events.html#a5b83e45fd5922657978cc36df24cc1c7":[10,8,4,7,3],
-"structspa__device__events.html#a64cea4459b8c4a483d0a2dd684f3e132":[10,8,4,7,1],
-"structspa__device__events.html#a830fadb39e2a8658f9b4cb663619cf4b":[10,8,4,7,4],
-"structspa__device__events.html#ad79a5bdce6b6bd7b299baa38330c96a7":[10,8,4,7,0],
-"structspa__device__info.html":[10,8,4,4],
-"structspa__device__info.html#a2692374f54a8d9f743474c4a3fcb8ebc":[10,8,4,4,2],
-"structspa__device__info.html#a2ef8690873a8db10e6c29357ea4a216c":[10,8,4,4,3],
-"structspa__device__info.html#a394aa2b1d356ce8e510330aedd38ff63":[10,8,4,4,0],
-"structspa__device__info.html#a5184282839436a8b87d505b4b17cffbd":[10,8,4,4,4],
-"structspa__device__info.html#afbe429acf565ab384929f0ccf76fc49c":[10,8,4,4,1],
-"structspa__device__methods.html":[10,8,4,8],
-"structspa__device__methods.html#a232006e407b2abdb2450a440172186ee":[10,8,4,8,0],
-"structspa__device__methods.html#a25f49777c2e75988cd5fd7fc490479c8":[10,8,4,8,2],
-"structspa__device__methods.html#a3c9741ff5de62f38f2e3eca50ae24a10":[10,8,4,8,3],
-"structspa__device__methods.html#aa5bfc95e88b2f018dddc55fb64899215":[10,8,4,8,4],
-"structspa__device__methods.html#aac8a0ceced3319473ab3edd4271e1d64":[10,8,4,8,1],
-"structspa__device__object__info.html":[10,8,4,5],
-"structspa__device__object__info.html#a0758afd0518197c48d5d76cdc14526e3":[10,8,4,5,0],
-"structspa__device__object__info.html#a4ed767ff310d6f2e1d4cd78f3a7c3f6f":[10,8,4,5,1],
-"structspa__device__object__info.html#a702111c5873243c93551073552863666":[10,8,4,5,3],
-"structspa__device__object__info.html#a9b6645d2c0b8b3679833ad122cb299a1":[10,8,4,5,2],
-"structspa__device__object__info.html#aec61b33f732c10087d40e9c0d97bdcb0":[10,8,4,5,4],
-"structspa__dict.html":[10,8,8,2,2],
-"structspa__dict.html#a1f1083da3fcd51b9c3eb22cc8f1d54e0":[10,8,8,2,2,2],
-"structspa__dict.html#a3b3b78bfe5fffe13a10720bb7099c399":[10,8,8,2,2,1],
-"structspa__dict.html#a88aca003fcdbc47599ffb3e2737f1a69":[10,8,8,2,2,0]
+"structspa__device__events.html#a0b9ba211d7f484c7df9ac269d5b49af3":[10,8,4,7,2]
 };
